@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of oRTP 
+ * This file is part of oRTP
  * (see https://gitlab.linphone.org/BC/public/ortp).
  *
  * This program is free software: you can redistribute it and/or modify
@@ -22,30 +22,33 @@
  * \file payloadtype.h
  * \brief Definition of payload types
  *
-**/
+ **/
 
 #ifndef PAYLOADTYPE_H
 #define PAYLOADTYPE_H
 #include <ortp/port.h>
 
 #ifdef __cplusplus
-extern "C"{
+extern "C" {
 #endif
 
 /* flags for PayloadType::flags */
 
-#define	PAYLOAD_TYPE_ALLOCATED (1)
+#define PAYLOAD_TYPE_ALLOCATED (1)
 /*payload type represents a VBR codec*/
-#define	PAYLOAD_TYPE_IS_VBR (1<<1)
-#define	PAYLOAD_TYPE_RTCP_FEEDBACK_ENABLED (1<<2)
+#define PAYLOAD_TYPE_IS_VBR (1 << 1)
+#define PAYLOAD_TYPE_RTCP_FEEDBACK_ENABLED (1 << 2)
 /* private flags for future use by ortp */
-#define	PAYLOAD_TYPE_PRIV1 (1<<3)
+#define PAYLOAD_TYPE_PRIV1 (1 << 3)
 /* user flags, can be used by the application on top of oRTP */
-#define	PAYLOAD_TYPE_USER_FLAG_0 (1<<4)
-#define	PAYLOAD_TYPE_USER_FLAG_1 (1<<5)
-#define	PAYLOAD_TYPE_USER_FLAG_2 (1<<6)
-#define	PAYLOAD_TYPE_USER_FLAG_3 (1<<7)
-#define	PAYLOAD_TYPE_USER_FLAG_4 (1<<8)
+#define PAYLOAD_TYPE_USER_FLAG_0 (1 << 4)
+#define PAYLOAD_TYPE_USER_FLAG_1 (1 << 5)
+#define PAYLOAD_TYPE_USER_FLAG_2 (1 << 6)
+#define PAYLOAD_TYPE_USER_FLAG_3 (1 << 7)
+#define PAYLOAD_TYPE_USER_FLAG_4 (1 << 8)
+#define PAYLOAD_TYPE_USER_FLAG_5 (1 << 9)
+#define PAYLOAD_TYPE_USER_FLAG_6 (1 << 10)
+#define PAYLOAD_TYPE_USER_FLAG_7 (1 << 11)
 /* ask for more if you need*/
 
 #define PAYLOAD_TYPE_FLAG_CAN_RECV PAYLOAD_TYPE_USER_FLAG_1
@@ -55,7 +58,7 @@ extern "C"{
 #define PAYLOAD_AUDIO_PACKETIZED 1
 #define PAYLOAD_VIDEO 2
 #define PAYLOAD_TEXT 3
-#define PAYLOAD_OTHER 4  /* ?? */
+#define PAYLOAD_OTHER 4 /* ?? */
 
 #define PAYLOAD_TYPE_AVPF_NONE 0
 #define PAYLOAD_TYPE_AVPF_FIR (1 << 0)
@@ -64,26 +67,25 @@ extern "C"{
 #define PAYLOAD_TYPE_AVPF_RPSI (1 << 3)
 
 struct _PayloadTypeAvpfParams {
-	unsigned char features; /**< A bitmask of PAYLOAD_TYPE_AVPF_* macros. */
+	unsigned char features;    /**< A bitmask of PAYLOAD_TYPE_AVPF_* macros. */
 	bool_t rpsi_compatibility; /*< Linphone uses positive feeback for RPSI. However first versions handling
-		AVPF wrongly declared RPSI as negative feedback, so this is kept for compatibility
-		with these versions but will probably be removed at some point in time. */
-	uint16_t trr_interval; /**< The interval in milliseconds between regular RTCP packets. */
+	    AVPF wrongly declared RPSI as negative feedback, so this is kept for compatibility
+	    with these versions but will probably be removed at some point in time. */
+	uint16_t trr_interval;     /**< The interval in milliseconds between regular RTCP packets. */
 };
 
-struct _OrtpPayloadType
-{
-	int type; /**< one of PAYLOAD_* macros*/
-	int clock_rate; /**< rtp clock rate*/
-	char bits_per_sample;	/* in case of continuous audio data */
+struct _OrtpPayloadType {
+	int type;             /**< one of PAYLOAD_* macros*/
+	int clock_rate;       /**< rtp clock rate*/
+	char bits_per_sample; /* in case of continuous audio data */
 	char *zero_pattern;
 	int pattern_length;
 	/* other useful information for the application*/
-	int normal_bitrate;	/*in bit/s */
-	char *mime_type; /**<actually the submime, ex: pcm, pcma, gsm*/
-	int channels; /**< number of channels of audio */
-	char *recv_fmtp; /* various format parameters for the incoming stream */
-	char *send_fmtp; /* various format parameters for the outgoing stream */
+	int normal_bitrate;                 /*in bit/s */
+	char *mime_type;                    /**<actually the submime, ex: pcm, pcma, gsm*/
+	int channels;                       /**< number of channels of audio */
+	char *recv_fmtp;                    /* various format parameters for the incoming stream */
+	char *send_fmtp;                    /* various format parameters for the outgoing stream */
 	struct _PayloadTypeAvpfParams avpf; /* AVPF parameters */
 	int flags;
 	void *user_data;
@@ -96,10 +98,9 @@ typedef OrtpPayloadType PayloadType;
 typedef struct _PayloadTypeAvpfParams PayloadTypeAvpfParams;
 #endif
 
-#define payload_type_set_flag(pt,flag) (pt)->flags|=((int)flag)
-#define payload_type_unset_flag(pt,flag) (pt)->flags&=(~(int)flag)
-#define payload_type_get_flags(pt)	(pt)->flags
-
+#define payload_type_set_flag(pt, flag) (pt)->flags |= ((int)flag)
+#define payload_type_unset_flag(pt, flag) (pt)->flags &= (~(int)flag)
+#define payload_type_get_flags(pt) (pt)->flags
 
 ORTP_PUBLIC PayloadType *payload_type_new(void);
 ORTP_PUBLIC PayloadType *payload_type_clone(const PayloadType *payload);
@@ -109,19 +110,18 @@ ORTP_PUBLIC void payload_type_set_recv_fmtp(PayloadType *pt, const char *fmtp);
 ORTP_PUBLIC void payload_type_set_send_fmtp(PayloadType *pt, const char *fmtp);
 ORTP_PUBLIC void payload_type_append_recv_fmtp(PayloadType *pt, const char *fmtp);
 ORTP_PUBLIC void payload_type_append_send_fmtp(PayloadType *pt, const char *fmtp);
-#define payload_type_get_avpf_params(pt)	((pt)->avpf)
+#define payload_type_get_avpf_params(pt) ((pt)->avpf)
 ORTP_PUBLIC void payload_type_set_avpf_params(PayloadType *pt, PayloadTypeAvpfParams params);
 ORTP_PUBLIC bool_t payload_type_is_vbr(const PayloadType *pt);
 
-#define payload_type_get_bitrate(pt)	((pt)->normal_bitrate)
-#define payload_type_get_rate(pt)		((pt)->clock_rate)
-#define payload_type_get_mime(pt)		((pt)->mime_type)
+#define payload_type_get_bitrate(pt) ((pt)->normal_bitrate)
+#define payload_type_get_rate(pt) ((pt)->clock_rate)
+#define payload_type_get_mime(pt) ((pt)->mime_type)
 
 ORTP_PUBLIC bool_t fmtp_get_value(const char *fmtp, const char *param_name, char *result, size_t result_len);
 
-#define payload_type_set_user_data(pt,p)	(pt)->user_data=(p)
-#define payload_type_get_user_data(pt)		((pt)->user_data)
-
+#define payload_type_set_user_data(pt, p) (pt)->user_data = (p)
+#define payload_type_get_user_data(pt) ((pt)->user_data)
 
 /* some payload types */
 /* audio */
@@ -183,9 +183,10 @@ ORTP_VAR_PUBLIC PayloadType payload_type_h265;
 ORTP_VAR_PUBLIC PayloadType payload_type_x_snow;
 ORTP_VAR_PUBLIC PayloadType payload_type_jpeg;
 ORTP_VAR_PUBLIC PayloadType payload_type_vp8;
+ORTP_VAR_PUBLIC PayloadType payload_type_av1;
 
 ORTP_VAR_PUBLIC PayloadType payload_type_g722;
-
+ORTP_VAR_PUBLIC PayloadType payload_type_flexfec;
 /* text */
 ORTP_VAR_PUBLIC PayloadType payload_type_t140;
 ORTP_VAR_PUBLIC PayloadType payload_type_t140_red;
