@@ -1,26 +1,27 @@
 /*
-  The oRTP library is an RTP (Realtime Transport Protocol - rfc3550) stack.
-  Copyright (C) 2001  Simon MORLAT simon.morlat@linphone.org
-
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
-
-  You should have received a copy of the GNU Lesser General Public
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/
-
+ * Copyright (c) 2010-2022 Belledonne Communications SARL.
+ *
+ * This file is part of oRTP
+ * (see https://gitlab.linphone.org/BC/public/ortp).
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #ifndef RTCP_H
 #define RTCP_H
 
+#include "ortp/str_utils.h"
 #include <ortp/port.h>
 
 #define RTCP_MAX_RECV_BUFSIZE 1500
@@ -31,7 +32,7 @@
 #define RTCP_SSRC_FIELD_SIZE 4
 
 #ifdef __cplusplus
-extern "C"{
+extern "C" {
 #endif
 
 /* RTCP common header */
@@ -47,40 +48,36 @@ typedef enum {
 	RTCP_XR = 207
 } rtcp_type_t;
 
-
-typedef struct rtcp_common_header
-{
+typedef struct rtcp_common_header {
 #ifdef ORTP_BIGENDIAN
-	uint16_t version:2;
-	uint16_t padbit:1;
-	uint16_t rc:5;
-	uint16_t packet_type:8;
+	uint16_t version : 2;
+	uint16_t padbit : 1;
+	uint16_t rc : 5;
+	uint16_t packet_type : 8;
 #else
-	uint16_t rc:5;
-	uint16_t padbit:1;
-	uint16_t version:2;
-	uint16_t packet_type:8;
+	uint16_t rc : 5;
+	uint16_t padbit : 1;
+	uint16_t version : 2;
+	uint16_t packet_type : 8;
 #endif
-	uint16_t length:16;
+	uint16_t length : 16;
 } rtcp_common_header_t;
 
-#define rtcp_common_header_set_version(ch,v) (ch)->version=v
-#define rtcp_common_header_set_padbit(ch,p) (ch)->padbit=p
-#define rtcp_common_header_set_rc(ch,rc) (ch)->rc=rc
-#define rtcp_common_header_set_packet_type(ch,pt) (ch)->packet_type=pt
-#define rtcp_common_header_set_length(ch,l)	(ch)->length=htons(l)
+#define rtcp_common_header_set_version(ch, v) (ch)->version = v
+#define rtcp_common_header_set_padbit(ch, p) (ch)->padbit = p
+#define rtcp_common_header_set_rc(ch, rc) (ch)->rc = rc
+#define rtcp_common_header_set_packet_type(ch, pt) (ch)->packet_type = pt
+#define rtcp_common_header_set_length(ch, l) (ch)->length = htons(l)
 
 #define rtcp_common_header_get_version(ch) ((ch)->version)
 #define rtcp_common_header_get_padbit(ch) ((ch)->padbit)
 #define rtcp_common_header_get_rc(ch) ((ch)->rc)
 #define rtcp_common_header_get_packet_type(ch) ((ch)->packet_type)
-#define rtcp_common_header_get_length(ch)	ntohs((ch)->length)
+#define rtcp_common_header_get_length(ch) ntohs((ch)->length)
 
+/* RTCP SR or RR  packets */
 
-/* SR or RR  packets */
-
-typedef struct sender_info
-{
+typedef struct sender_info {
 	uint32_t ntp_timestamp_msw;
 	uint32_t ntp_timestamp_lsw;
 	uint32_t rtp_timestamp;
@@ -88,62 +85,56 @@ typedef struct sender_info
 	uint32_t senders_octet_count;
 } sender_info_t;
 
-uint64_t sender_info_get_ntp_timestamp(const sender_info_t *si);
-#define sender_info_get_rtp_timestamp(si)	((si)->rtp_timestamp)
-#define sender_info_get_packet_count(si) \
-	ntohl((si)->senders_packet_count)
-#define sender_info_get_octet_count(si) \
-	ntohl((si)->senders_octet_count)
+static ORTP_INLINE uint64_t sender_info_get_ntp_timestamp(const sender_info_t *si) {
+	return ((((uint64_t)ntohl(si->ntp_timestamp_msw)) << 32) + ((uint64_t)ntohl(si->ntp_timestamp_lsw)));
+}
+#define sender_info_get_rtp_timestamp(si) ntohl((si)->rtp_timestamp)
+#define sender_info_get_packet_count(si) ntohl((si)->senders_packet_count)
+#define sender_info_get_octet_count(si) ntohl((si)->senders_octet_count)
 
-
-typedef struct report_block
-{
+typedef struct report_block {
 	uint32_t ssrc;
-	uint32_t fl_cnpl;/*fraction lost + cumulative number of packet lost*/
+	uint32_t fl_cnpl;              /*fraction lost + cumulative number of packet lost*/
 	uint32_t ext_high_seq_num_rec; /*extended highest sequence number received */
 	uint32_t interarrival_jitter;
-	uint32_t lsr; /*last SR */
+	uint32_t lsr;               /*last SR */
 	uint32_t delay_snc_last_sr; /*delay since last sr*/
 } report_block_t;
 
-static ORTP_INLINE uint32_t report_block_get_ssrc(const report_block_t * rb) {
+static ORTP_INLINE uint32_t report_block_get_ssrc(const report_block_t *rb) {
 	return ntohl(rb->ssrc);
 }
-static ORTP_INLINE uint32_t report_block_get_high_ext_seq(const report_block_t * rb) {
+static ORTP_INLINE uint32_t report_block_get_high_ext_seq(const report_block_t *rb) {
 	return ntohl(rb->ext_high_seq_num_rec);
 }
-static ORTP_INLINE uint32_t report_block_get_interarrival_jitter(const report_block_t * rb) {
+static ORTP_INLINE uint32_t report_block_get_interarrival_jitter(const report_block_t *rb) {
 	return ntohl(rb->interarrival_jitter);
 }
 
-static ORTP_INLINE uint32_t report_block_get_last_SR_time(const report_block_t * rb) {
+static ORTP_INLINE uint32_t report_block_get_last_SR_time(const report_block_t *rb) {
 	return ntohl(rb->lsr);
 }
-static ORTP_INLINE uint32_t report_block_get_last_SR_delay(const report_block_t * rb) {
+static ORTP_INLINE uint32_t report_block_get_last_SR_delay(const report_block_t *rb) {
 	return ntohl(rb->delay_snc_last_sr);
 }
-static ORTP_INLINE uint32_t report_block_get_fraction_lost(const report_block_t * rb) {
-	return (ntohl(rb->fl_cnpl)>>24);
+static ORTP_INLINE uint32_t report_block_get_fraction_lost(const report_block_t *rb) {
+	return (ntohl(rb->fl_cnpl) >> 24);
 }
-static ORTP_INLINE int32_t report_block_get_cum_packet_lost(const report_block_t * rb){
-	int cum_loss = ntohl(rb->fl_cnpl);
-	if (((cum_loss>>23)&1)==0)
-		return 0x00FFFFFF & cum_loss;
-	else
-		return 0xFF000000 | (cum_loss-0xFFFFFF-1);
+static ORTP_INLINE int32_t report_block_get_cum_packet_lost(const report_block_t *rb) {
+	uint32_t cum_loss = (uint32_t)ntohl(rb->fl_cnpl);
+	if (((cum_loss >> 23) & 1) == 0) return (int32_t)(0x00FFFFFF & cum_loss);
+	else return (int32_t)(0xFF000000 | (cum_loss - 0xFFFFFF - 1));
 }
 
-static ORTP_INLINE void report_block_set_fraction_lost(report_block_t * rb, int fl){
-	rb->fl_cnpl = htonl( (ntohl(rb->fl_cnpl) & 0xFFFFFF) | (fl&0xFF)<<24);
+static ORTP_INLINE void report_block_set_fraction_lost(report_block_t *rb, int fl) {
+	rb->fl_cnpl = (uint32_t)htonl(((uint32_t)ntohl(rb->fl_cnpl) & 0xFFFFFF) | ((uint32_t)fl & 0xFF) << 24);
 }
 
-static ORTP_INLINE void report_block_set_cum_packet_lost(report_block_t * rb, int64_t cpl) {
-	uint32_t clamp = (uint32_t)((1<<24) + ((cpl>=0) ? (cpl>0x7FFFFF?0x7FFFFF:cpl) : (-cpl>0x800000?-0x800000:cpl)));
+static ORTP_INLINE void report_block_set_cum_packet_lost(report_block_t *rb, int64_t cpl) {
+	uint32_t clamp =
+	    (uint32_t)((1 << 24) + ((cpl >= 0) ? (cpl > 0x7FFFFF ? 0x7FFFFF : cpl) : (-cpl > 0x800000 ? -0x800000 : cpl)));
 
-	rb->fl_cnpl=htonl(
-			(ntohl(rb->fl_cnpl) & 0xFF000000) |
-			(cpl >= 0 ? clamp&0x7FFFFF : clamp|0x800000)
-		);
+	rb->fl_cnpl = htonl((ntohl(rb->fl_cnpl) & 0xFF000000) | (cpl >= 0 ? clamp & 0x7FFFFF : clamp | 0x800000));
 }
 
 /* SDES packets */
@@ -158,19 +149,18 @@ typedef enum {
 	RTCP_SDES_TOOL = 6,
 	RTCP_SDES_NOTE = 7,
 	RTCP_SDES_PRIV = 8,
-	RTCP_SDES_MAX = 9
+	RTCP_SDES_MID = 10, /* TODO: change this value when his identifier will be assigned */
+	RTCP_SDES_MAX = 11
 } rtcp_sdes_type_t;
 
-typedef struct sdes_chunk
-{
+typedef struct sdes_chunk {
 	uint32_t csrc;
 } sdes_chunk_t;
 
+#define sdes_chunk_get_ssrc(m) ntohl(((sdes_chunk_t *)((m)->b_rptr))->csrc)
+#define sdes_chunk_get_csrc(c) ntohl((c)->csrc)
 
-#define sdes_chunk_get_csrc(c)	ntohl((c)->csrc)
-
-typedef struct sdes_item
-{
+typedef struct sdes_item {
 	uint8_t item_type;
 	uint8_t len;
 	char content[1];
@@ -183,21 +173,18 @@ typedef struct sdes_item
 
 /* RTCP bye packet */
 
-typedef struct rtcp_bye_reason
-{
+typedef struct rtcp_bye_reason {
 	uint8_t len;
 	char content[1];
 } rtcp_bye_reason_t;
 
-typedef struct rtcp_bye
-{
+typedef struct rtcp_bye {
 	rtcp_common_header_t ch;
-	uint32_t ssrc[1];  /* the bye may contain several ssrc/csrc */
+	uint32_t ssrc[1]; /* the bye may contain several ssrc/csrc */
 } rtcp_bye_t;
 #define RTCP_BYE_HEADER_SIZE sizeof(rtcp_bye_t)
 #define RTCP_BYE_REASON_MAX_STRING_SIZE 255
 
-
 /* RTCP XR packet */
 
 #define RTCP_XR_VOIP_METRICS_CONFIG_PLC_STD ((1 << 7) | (1 << 6))
@@ -291,11 +278,8 @@ typedef struct rtcp_xr_voip_metrics_report_block {
 
 #define MIN_RTCP_XR_PACKET_SIZE (sizeof(rtcp_xr_header_t) + 4)
 
-typedef enum {
-	RTCP_RTPFB_NACK = 1,
-	RTCP_RTPFB_TMMBR = 3,
-	RTCP_RTPFB_TMMBN = 4
-} rtcp_rtpfb_type_t;
+/* RTCP FB packet */
+typedef enum { RTCP_RTPFB_NACK = 1, RTCP_RTPFB_TMMBR = 3, RTCP_RTPFB_TMMBN = 4 } rtcp_rtpfb_type_t;
 
 typedef enum {
 	RTCP_PSFB_PLI = 1,
@@ -326,18 +310,15 @@ typedef struct rtcp_fb_tmmbr_fci {
 } rtcp_fb_tmmbr_fci_t;
 
 #define rtcp_fb_tmmbr_fci_get_ssrc(tmmbr) ntohl((tmmbr)->ssrc)
-#define rtcp_fb_tmmbr_fci_get_mxtbr_exp(tmmbr) \
-	((uint8_t)((ntohl((tmmbr)->value) >> 26) & 0x0000003F))
-#define rtcp_fb_tmmbr_fci_set_mxtbr_exp(tmmbr, mxtbr_exp) \
-	((tmmbr)->value) = htonl((ntohl((tmmbr)->value) & 0x03FFFFFF) | (((mxtbr_exp) & 0x0000003F) << 26))
-#define rtcp_fb_tmmbr_fci_get_mxtbr_mantissa(tmmbr) \
-	((uint32_t)((ntohl((tmmbr)->value) >> 9) & 0x0001FFFF))
-#define rtcp_fb_tmmbr_fci_set_mxtbr_mantissa(tmmbr, mxtbr_mantissa) \
-	((tmmbr)->value) = htonl((ntohl((tmmbr)->value) & 0xFC0001FF) | (((mxtbr_mantissa) & 0x0001FFFF) << 9))
-#define rtcp_fb_tmmbr_fci_get_measured_overhead(tmmbr) \
-	((uint16_t)(ntohl((tmmbr)->value) & 0x000001FF))
-#define rtcp_fb_tmmbr_fci_set_measured_overhead(tmmbr, measured_overhead) \
-	((tmmbr)->value) = htonl((ntohl((tmmbr)->value) & 0xFFFFFE00) | ((measured_overhead) & 0x000001FF))
+#define rtcp_fb_tmmbr_fci_get_mxtbr_exp(tmmbr) ((uint8_t)((ntohl((tmmbr)->value) >> 26) & 0x0000003F))
+#define rtcp_fb_tmmbr_fci_set_mxtbr_exp(tmmbr, mxtbr_exp)                                                              \
+	((tmmbr)->value) = htonl((ntohl((tmmbr)->value) & 0x03FFFFFF) | (((mxtbr_exp)&0x0000003F) << 26))
+#define rtcp_fb_tmmbr_fci_get_mxtbr_mantissa(tmmbr) ((uint32_t)((ntohl((tmmbr)->value) >> 9) & 0x0001FFFF))
+#define rtcp_fb_tmmbr_fci_set_mxtbr_mantissa(tmmbr, mxtbr_mantissa)                                                    \
+	((tmmbr)->value) = htonl((ntohl((tmmbr)->value) & 0xFC0001FF) | (((mxtbr_mantissa)&0x0001FFFF) << 9))
+#define rtcp_fb_tmmbr_fci_get_measured_overhead(tmmbr) ((uint16_t)(ntohl((tmmbr)->value) & 0x000001FF))
+#define rtcp_fb_tmmbr_fci_set_measured_overhead(tmmbr, measured_overhead)                                              \
+	((tmmbr)->value) = htonl((ntohl((tmmbr)->value) & 0xFFFFFE00) | ((measured_overhead)&0x000001FF))
 
 typedef struct rtcp_fb_fir_fci {
 	uint32_t ssrc;
@@ -353,18 +334,15 @@ typedef struct rtcp_fb_sli_fci {
 	uint32_t value;
 } rtcp_fb_sli_fci_t;
 
-#define rtcp_fb_sli_fci_get_first(fci) \
-	((uint16_t)((ntohl((fci)->value) >> 19) & 0x00001FFF))
-#define rtcp_fb_sli_fci_set_first(fci, first) \
-	((fci)->value) = htonl((ntohl((fci)->value) & 0x0007FFFF) | (((first) & 0x00001FFF) << 19))
-#define rtcp_fb_sli_fci_get_number(fci) \
-	((uint16_t)((ntohl((fci)->value) >> 6) & 0x00001FFF))
-#define rtcp_fb_sli_fci_set_number(fci, number) \
-	((fci)->value) = htonl((ntohl((fci)->value) & 0xFFF8003F) | (((number) & 0x00001FFF) << 6))
-#define rtcp_fb_sli_fci_get_picture_id(fci) \
-	((uint8_t)(ntohl((fci)->value) & 0x0000003F))
-#define rtcp_fb_sli_fci_set_picture_id(fci, picture_id) \
-	((fci)->value) = htonl((ntohl((fci)->value) & 0xFFFFFFC0) | ((picture_id) & 0x0000003F))
+#define rtcp_fb_sli_fci_get_first(fci) ((uint16_t)((ntohl((fci)->value) >> 19) & 0x00001FFF))
+#define rtcp_fb_sli_fci_set_first(fci, first)                                                                          \
+	((fci)->value) = htonl((ntohl((fci)->value) & 0x0007FFFF) | (((first)&0x00001FFF) << 19))
+#define rtcp_fb_sli_fci_get_number(fci) ((uint16_t)((ntohl((fci)->value) >> 6) & 0x00001FFF))
+#define rtcp_fb_sli_fci_set_number(fci, number)                                                                        \
+	((fci)->value) = htonl((ntohl((fci)->value) & 0xFFF8003F) | (((number)&0x00001FFF) << 6))
+#define rtcp_fb_sli_fci_get_picture_id(fci) ((uint8_t)(ntohl((fci)->value) & 0x0000003F))
+#define rtcp_fb_sli_fci_set_picture_id(fci, picture_id)                                                                \
+	((fci)->value) = htonl((ntohl((fci)->value) & 0xFFFFFFC0) | ((picture_id)&0x0000003F))
 
 typedef struct rtcp_fb_rpsi_fci {
 	uint8_t pb;
@@ -378,22 +356,22 @@ typedef struct rtcp_fb_rpsi_fci {
 #define MIN_RTCP_PSFB_PACKET_SIZE (sizeof(rtcp_common_header_t) + sizeof(rtcp_fb_header_t))
 #define MIN_RTCP_RTPFB_PACKET_SIZE (sizeof(rtcp_common_header_t) + sizeof(rtcp_fb_header_t))
 
+/* RTCP structs */
 
-
-typedef struct rtcp_sr{
+typedef struct rtcp_sr {
 	rtcp_common_header_t ch;
 	uint32_t ssrc;
 	sender_info_t si;
 	report_block_t rb[1];
 } rtcp_sr_t;
 
-typedef struct rtcp_rr{
+typedef struct rtcp_rr {
 	rtcp_common_header_t ch;
 	uint32_t ssrc;
 	report_block_t rb[1];
 } rtcp_rr_t;
 
-typedef struct rtcp_app{
+typedef struct rtcp_app {
 	rtcp_common_header_t ch;
 	uint32_t ssrc;
 	char name[4];
@@ -404,35 +382,48 @@ struct _RtpStream;
 ORTP_PUBLIC void rtp_session_rtcp_process_send(struct _RtpSession *s);
 ORTP_PUBLIC void rtp_session_rtcp_process_recv(struct _RtpSession *s);
 
-
 #define RTCP_DEFAULT_REPORT_INTERVAL 5000 /* in milliseconds */
 
-
 /* packet parsing api */
 
+/*return the size of the rtcp packet*/
+ORTP_PUBLIC size_t rtcp_get_size(const mblk_t *m);
 /*in case of coumpound packet, set read pointer of m to the beginning of the next RTCP
 packet */
-ORTP_PUBLIC bool_t rtcp_next_packet(mblk_t *m);
-/* put the read pointer at the first RTCP packet of the compound packet (as before any previous calls ot rtcp_next_packet() */
-ORTP_PUBLIC void rtcp_rewind(mblk_t *m);
+ORTP_PUBLIC ORTP_DEPRECATED bool_t rtcp_next_packet(mblk_t *m);
+/* put the read pointer at the first RTCP packet of the compound packet (as before any previous calls ot
+ * rtcp_next_packet() */
+ORTP_PUBLIC ORTP_DEPRECATED void rtcp_rewind(mblk_t *m);
+
+typedef struct _RtcpParserContext {
+	mblk_t *current_packet;
+	uint8_t *start;
+} RtcpParserContext;
+
+ORTP_PUBLIC const mblk_t *rtcp_parser_context_init(RtcpParserContext *context, const mblk_t *compound_packet);
+ORTP_PUBLIC const mblk_t *rtcp_parser_context_next_packet(RtcpParserContext *context);
+ORTP_PUBLIC const mblk_t *rtcp_parser_context_start(RtcpParserContext *context);
+ORTP_PUBLIC void rtcp_parser_context_uninit(RtcpParserContext *context);
+
 /* get common header*/
-ORTP_PUBLIC const rtcp_common_header_t * rtcp_get_common_header(const mblk_t *m);
+ORTP_PUBLIC const rtcp_common_header_t *rtcp_get_common_header(const mblk_t *m);
 
 /*Sender Report accessors */
 /* check if this packet is a SR and if it is correct */
 ORTP_PUBLIC bool_t rtcp_is_SR(const mblk_t *m);
 ORTP_PUBLIC uint32_t rtcp_SR_get_ssrc(const mblk_t *m);
-ORTP_PUBLIC const sender_info_t * rtcp_SR_get_sender_info(const mblk_t *m);
-ORTP_PUBLIC const report_block_t * rtcp_SR_get_report_block(const mblk_t *m, int idx);
+ORTP_PUBLIC const sender_info_t *rtcp_SR_get_sender_info(const mblk_t *m);
+ORTP_PUBLIC const report_block_t *rtcp_SR_get_report_block(const mblk_t *m, int idx);
 
 /*Receiver report accessors*/
 ORTP_PUBLIC bool_t rtcp_is_RR(const mblk_t *m);
 ORTP_PUBLIC uint32_t rtcp_RR_get_ssrc(const mblk_t *m);
-ORTP_PUBLIC const report_block_t * rtcp_RR_get_report_block(const mblk_t *m,int idx);
+ORTP_PUBLIC const report_block_t *rtcp_RR_get_report_block(const mblk_t *m, int idx);
 
 /*SDES accessors */
 ORTP_PUBLIC bool_t rtcp_is_SDES(const mblk_t *m);
-typedef void (*SdesItemFoundCallback)(void *user_data, uint32_t csrc, rtcp_sdes_type_t t, const char *content, uint8_t content_len);
+typedef void (*SdesItemFoundCallback)(
+    void *user_data, uint32_t csrc, rtcp_sdes_type_t t, const char *content, uint8_t content_len);
 ORTP_PUBLIC void rtcp_sdes_parse(const mblk_t *m, SdesItemFoundCallback cb, void *user_data);
 
 /*BYE accessors */
@@ -496,8 +487,15 @@ ORTP_PUBLIC uint16_t rtcp_XR_voip_metrics_get_jb_abs_max(const mblk_t *m);
 /* RTCP RTPFB accessors */
 ORTP_PUBLIC bool_t rtcp_is_RTPFB(const mblk_t *m);
 ORTP_PUBLIC rtcp_rtpfb_type_t rtcp_RTPFB_get_type(const mblk_t *m);
-ORTP_PUBLIC rtcp_fb_generic_nack_fci_t * rtcp_RTPFB_generic_nack_get_fci(const mblk_t *m);
-ORTP_PUBLIC rtcp_fb_tmmbr_fci_t * rtcp_RTPFB_tmmbr_get_fci(const mblk_t *m);
+ORTP_PUBLIC rtcp_fb_generic_nack_fci_t *rtcp_RTPFB_generic_nack_get_fci(const mblk_t *m);
+ORTP_PUBLIC rtcp_fb_tmmbr_fci_t *rtcp_RTPFB_tmmbr_get_fci(const mblk_t *m);
+/**
+ * Return the maximum bitrate in bits / sec contained in the packet.
+ *
+ * @param m RTCP TMMBR packet to read
+ * @return maximum bitrate in bits / sec.
+ */
+ORTP_PUBLIC uint64_t rtcp_RTPFB_tmmbr_get_max_bitrate(const mblk_t *m);
 ORTP_PUBLIC uint32_t rtcp_RTPFB_get_packet_sender_ssrc(const mblk_t *m);
 ORTP_PUBLIC uint32_t rtcp_RTPFB_get_media_source_ssrc(const mblk_t *m);
 
@@ -506,13 +504,12 @@ ORTP_PUBLIC bool_t rtcp_is_PSFB(const mblk_t *m);
 ORTP_PUBLIC rtcp_psfb_type_t rtcp_PSFB_get_type(const mblk_t *m);
 ORTP_PUBLIC uint32_t rtcp_PSFB_get_packet_sender_ssrc(const mblk_t *m);
 ORTP_PUBLIC uint32_t rtcp_PSFB_get_media_source_ssrc(const mblk_t *m);
-ORTP_PUBLIC rtcp_fb_fir_fci_t * rtcp_PSFB_fir_get_fci(const mblk_t *m, unsigned int idx);
-ORTP_PUBLIC rtcp_fb_sli_fci_t * rtcp_PSFB_sli_get_fci(const mblk_t *m, unsigned int idx);
-ORTP_PUBLIC rtcp_fb_rpsi_fci_t * rtcp_PSFB_rpsi_get_fci(const mblk_t *m);
+ORTP_PUBLIC rtcp_fb_fir_fci_t *rtcp_PSFB_fir_get_fci(const mblk_t *m, unsigned int idx);
+ORTP_PUBLIC rtcp_fb_sli_fci_t *rtcp_PSFB_sli_get_fci(const mblk_t *m, unsigned int idx);
+ORTP_PUBLIC rtcp_fb_rpsi_fci_t *rtcp_PSFB_rpsi_get_fci(const mblk_t *m);
 ORTP_PUBLIC uint16_t rtcp_PSFB_rpsi_get_fci_bit_string_len(const mblk_t *m);
 
-
-typedef struct OrtpLossRateEstimator{
+typedef struct OrtpLossRateEstimator {
 	int min_packet_count_interval;
 	uint64_t min_time_ms_interval;
 	uint64_t last_estimate_time_ms;
@@ -520,22 +517,24 @@ typedef struct OrtpLossRateEstimator{
 	int32_t last_ext_seq;
 	float loss_rate;
 	/**
-	* Total number of outgoing duplicate packets on last
-	* #ortp_loss_rate_estimator_process_report_block iteration.
-	**/
-	int32_t last_dup_packet_sent_count;
+	 * Total number of outgoing duplicate packets on last
+	 * ortp_loss_rate_estimator_process_report_block iteration.
+	 **/
+	int64_t last_dup_packet_sent_count;
 	/**
-	* Total number of outgoing unique packets on last
-	* #ortp_loss_rate_estimator_process_report_block iteration.
-	**/
-	int32_t last_packet_sent_count;
-}OrtpLossRateEstimator;
+	 * Total number of outgoing unique packets on last
+	 * ortp_loss_rate_estimator_process_report_block iteration.
+	 **/
+	int64_t last_packet_sent_count;
+} OrtpLossRateEstimator;
 
+ORTP_PUBLIC OrtpLossRateEstimator *
+ortp_loss_rate_estimator_new(int min_packet_count_interval, uint64_t min_time_ms_interval, struct _RtpSession *session);
 
-ORTP_PUBLIC OrtpLossRateEstimator * ortp_loss_rate_estimator_new(int min_packet_count_interval, uint64_t min_time_ms_interval, struct _RtpSession *session);
-
-ORTP_PUBLIC void ortp_loss_rate_estimator_init(OrtpLossRateEstimator *obj, int min_packet_count_interval, uint64_t min_time_ms_interval, struct _RtpSession *session);
-
+ORTP_PUBLIC void ortp_loss_rate_estimator_init(OrtpLossRateEstimator *obj,
+                                               int min_packet_count_interval,
+                                               uint64_t min_time_ms_interval,
+                                               struct _RtpSession *session);
 
 /**
  * Process an incoming report block to compute loss rate percentage. It tries to compute
@@ -548,13 +547,13 @@ ORTP_PUBLIC void ortp_loss_rate_estimator_init(OrtpLossRateEstimator *obj, int m
  * cumulative loss factor which allows us to take into consideration duplicates
  * packets as well.
  * @param[in] obj #OrtpLossRateEstimator object.
- * @param[in] stream #RtpStream stream in which the report block to consider belongs.
+ * @param[in] session #_RtpSession stream in which the report block to consider belongs.
  * @param[in] rb Report block to analyze.
  * @return TRUE if a new loss rate estimation is ready, FALSE otherwise.
  */
 ORTP_PUBLIC bool_t ortp_loss_rate_estimator_process_report_block(OrtpLossRateEstimator *obj,
-																 const struct _RtpStream *stream,
-																 const report_block_t *rb);
+                                                                 const struct _RtpSession *session,
+                                                                 const report_block_t *rb);
 /**
  * Get the latest loss rate in percentage estimation computed.
  *
@@ -563,8 +562,6 @@ ORTP_PUBLIC bool_t ortp_loss_rate_estimator_process_report_block(OrtpLossRateEst
  */
 ORTP_PUBLIC float ortp_loss_rate_estimator_get_value(OrtpLossRateEstimator *obj);
 
-ORTP_PUBLIC void ortp_loss_rate_estimator_uninit(OrtpLossRateEstimator *obj);
-
 ORTP_PUBLIC void ortp_loss_rate_estimator_destroy(OrtpLossRateEstimator *obj);
 
 #ifdef __cplusplus
